<html xmlns="http://www.w3.org/1999/xhtml"
      xmlns:py="http://genshi.edgewall.org/"
      xmlns:xi="http://www.w3.org/2001/XInclude">

  <xi:include href="master.html" />

<head>
  <meta content="text/html; charset=UTF-8" http-equiv="Content-Type" py:if="False"/>
  <title>Request Password Reset</title>
</head>

<body>
    <div>
        ${reset_password_form.display(action=action)}
    </div>
</body>
</html>
